@@ -4,8 +4,8 @@
 
 ;; Author: Al Haji-Ali <abdo.haji.ali at gmail.com>
 ;; Created: 2023
-;; Package-Version: 20250921.1717
-;; Package-Revision: af8eb956f0e6
+;; Package-Version: 20251106.746
+;; Package-Revision: fce42746bdaa
 ;; Package-Requires: ((emacs "29.1"))
 ;; Homepage: https://github.com/haji-ali/maccalfw
 ;; Keywords: calendar
@@ -43,7 +43,8 @@ second is the new event data."
   :type 'function
   :group 'ical-form)
 
-(defcustom ical-form-update-event-function #'ignore
+(defcustom ical-form-update-event-function
+  (lambda (&rest _) (error "`ical-form-update-event-function' not set correctly."))
   "Function to call to update/create event.
 
 Expected arguments are (OLD-DATA CHANGED-DATA) where OLD-DATA is
@@ -528,20 +529,27 @@ case the end time/date is set."
                  end-time-wid
                  (ical-form--format-time new-time))))))))))
 
-(defun ical-form-open (event calendars timezones)
+(defun ical-form-open (event calendars timezones &optional update-fn)
   "Open a buffer to display the details of EVENT.
 CALENDARS and TIMEZONES should be a list of calendars, and
-timezones to use in the form."
-  (pop-to-buffer (generate-new-buffer "*calender event*"))
-  (ical-form-mode)
-  (setq
-   ical-form--calendars calendars
-   ical-form--timezones timezones
-   ical-form--default-timezone
-   (cl-find-if
-    (lambda (x) (plist-get (cdr x) :default))
-    ical-form--timezones))
-  (ical-form-rebuild-buffer event t))
+timezones to use in the form.
+
+UPDATE-FN, if provided, is used to set
+`ical-form-update-event-function' locally in the new buffer."
+  (let ((buf (generate-new-buffer "*calender event*")))
+    (pop-to-buffer buf)
+    (ical-form-mode)
+    (when update-fn
+      (setq-local ical-form-update-event-function update-fn))
+    (setq
+     ical-form--calendars calendars
+     ical-form--timezones timezones
+     ical-form--default-timezone
+     (cl-find-if
+      (lambda (x) (plist-get (cdr x) :default))
+      ical-form--timezones))
+    (ical-form-rebuild-buffer event t)
+    buf))
 
 (defun ical-form-read-only (&rest _junk)
   "Ignoring the arguments, signal an error."
@@ -822,7 +830,9 @@ it."
      (list event nil)))
   (let ((timezones ical-form--timezones)
         (calendars ical-form--calendars)
-        (default-timezone ical-form--default-timezone))
+        (default-timezone ical-form--default-timezone)
+        (local-update-fn (local-variable-p 'ical-form-update-event-function))
+        (update-fn ical-form-update-event-function))
     (when (and
            (derived-mode-p 'ical-form-mode)
            (or (not (buffer-modified-p))
@@ -836,6 +846,12 @@ it."
 
       (ical-form-mode)
 
+      ;; Recover local-update function. We could instead mark the variable
+      ;; permanently local. But my thinking is that this variable is
+      ;; mode-specific and should not be
+      (when local-update-fn
+        (setq-local ical-form-update-event-function update-fn))
+
       (setq
        ical-form--calendars calendars
        ical-form--timezones timezones
